import suiAnalytics from '../src'
import {expect} from 'chai'
import sinon from 'sinon'

describe('#suiAnalytics', () => {
  describe('when the right mcvid is loaded', () => {
    beforeEach(() => {
      window.Visitor = {}
      window.Visitor.getInstance = sinon.stub().returns({
        getMarketingCloudVisitorID: sinon.stub().returns('fakeCloudId')
      })
    })

    afterEach(() => {
      delete window.Visitor
    })

    describe('when the track event is called', () => {
      beforeEach(() => {
        window.analytics = {
          ready: function(cb) {
            return new Promise((resolve, reject) => {
              resolve(cb())
            })
          },
          user: () => ({
            anonymousId: () => 'fakeAnonymousId',
            id: () => 'fakeId'
          }),
          track: sinon.stub()
        }
      })

      afterEach(() => {
        delete window.analytics
      })

      it('should add anonymousId as options trait', done => {
        suiAnalytics
          .track(
            'fakeEvent',
            {fakePropKey: 'fakePropValue'},
            {
              fakeOptionKey: 'fakeOptionValue',
              traits: {fakeTraitKey: 'fakeTraitValue'},
              integrations: {fakeIntegrationKey: 'fakeIntegrationValue'}
            }
          )
          .then(() => {
            sinon.assert.callCount(window.analytics.track, 1)
            expect(window.analytics.track.getCall(0).args[2]).to.deep.equal({
              fakeOptionKey: 'fakeOptionValue',
              traits: {
                fakeTraitKey: 'fakeTraitValue',
                anonymousId: 'fakeAnonymousId',
                userId: 'fakeId'
              },
              integrations: {
                fakeIntegrationKey: 'fakeIntegrationValue',
                'Adobe Analytics': {
                  marketingCloudVisitorId: 'fakeCloudId'
                }
              }
            })
            done()
          })
          .catch(done)
      })
    })
  })
})
